@@ -4,9 +4,9 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.51';
+our $VERSION = '0.54';
 
-use Exporter::Tiny qw();
+use Exporter qw( import );
 
 use Module::Implementation;
 
@@ -44,46 +44,54 @@ my %aliases = (
     zip           => 'mesh',
 );
 
-our @ISA         = qw(Exporter::Tiny);
-our @EXPORT_OK   = ( @subs, keys %aliases );
+our @EXPORT_OK = ( @subs, keys %aliases );
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
 {
     my $loader = Module::Implementation::build_loader_sub(
         implementations => [ 'XS', 'PP' ],
-        symbols => \@subs,
+        symbols         => \@subs,
     );
 
     $loader->();
 }
 
-use Scalar::Util;
 for my $alias ( keys %aliases ) {
+    ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no strict 'refs';
     *{$alias} = __PACKAGE__->can( $aliases{$alias} );
 }
 
+## no critic (Subroutines::ProhibitUnusedPrivateSubroutines)
 sub _XScompiled {
     return Module::Implementation::implementation_for(__PACKAGE__) eq 'XS';
 }
 
 1;
 
+# ABSTRACT: Provide the stuff missing in List::Util
+
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 List::SomeUtils - Provide the stuff missing in List::Util
 
+=head1 VERSION
+
+version 0.54
+
 =head1 SYNOPSIS
 
     # import specific functions
     use List::SomeUtils qw( any uniq );
 
-    my @values = qw( foo bar baz );
-    if ( any {/foo/} @values ) {
+    if ( any {/foo/} uniq @has_duplicates ) {
+
         # do stuff
     }
 
@@ -121,12 +129,16 @@ to get into tiring arguments about issues I don't really care about.
 
 =head2 Default behavior
 
-Nothing is exported by default. To import all of this module's symbols use the
-C<:all> tag. Otherwise functions can be imported by name as usual:
+Nothing by default. To import all of this module's symbols use the C<:all> tag.
+Otherwise functions can be imported by name as usual:
 
     use List::SomeUtils ':all';
 
-    use List::SomeUtils qw( any firstidx );
+    use List::SomeUtils qw{ any firstidx };
+
+Because historical changes to the API might make upgrading List::SomeUtils
+difficult for some projects, the legacy API is available via special import
+tags.
 
 =head1 FUNCTIONS
 
@@ -139,15 +151,19 @@ empty list:
 
 =over
 
-=item * Reduction to an identity (boolean)
+=item *
 
-=item * Result is undefined (three-valued)
+Reduction to an identity (boolean)
+
+=item *
+
+Result is undefined (three-valued)
 
 =back
 
 In the first case, the result of the junction applied to the empty list is
 determined by a mathematical reduction to an identity depending on whether
-the underlying comparison is "or" or "and". Conceptually:
+the underlying comparison is "or" or "and".  Conceptually:
 
                     "any are true"      "all are true"
                     --------------      --------------
@@ -155,10 +171,10 @@ the underlying comparison is "or" or "and". Conceptually:
     1 element:      A || 0              A && 1
     0 elements:     0                   1
 
-In the second case, three-value logic is desired, in which a junction applied
-to an empty list returns C<undef> rather than true or false.
+In the second case, three-value logic is desired, in which a junction
+applied to an empty list returns C<undef> rather than true or false
 
-Junctions with a C<_u> suffix implement three-valued logic. Those
+Junctions with a C<_u> suffix implement three-valued logic.  Those
 without are boolean.
 
 =head3 all BLOCK LIST
@@ -251,7 +267,7 @@ Evaluation of BLOCK will immediately stop at the second true value.
 =head3 apply BLOCK LIST
 
 Applies BLOCK to each item in LIST and returns a list of the values after BLOCK
-has been applied. In scalar context, the last element is returned. This
+has been applied. In scalar context, the last element is returned.  This
 function is similar to C<map> but will not modify the elements of the input
 list:
 
@@ -292,7 +308,7 @@ Inserts VALUE after the first item in LIST which is equal to STRING.
 
 Evaluates BLOCK for each pair of elements in ARRAY1 and ARRAY2 and returns a
 new list consisting of BLOCK's return values. The two elements are set to C<$a>
-and C<$b>. Note that those two are aliases to the original value so changing
+and C<$b>.  Note that those two are aliases to the original value so changing
 them will modify the input arrays.
 
   @a = (1 .. 5);
@@ -350,7 +366,7 @@ B<RT#49800> can be used to give feedback about this behavior.
 
 Returns a new list by stripping values in LIST occurring more than once by
 comparing the values as hash keys, except that undef is considered separate
-from ''. The order of elements in the returned list is the same as in LIST.
+from ''.  The order of elements in the returned list is the same as in LIST.
 In scalar context, returns the number of elements occurring only once in LIST.
 
   my @x = singleton 1,1,2,2,3,4,5 # returns 3 4 5
@@ -410,9 +426,9 @@ Negative values are only ok when they refer to a partition previously created:
 =head3 each_array ARRAY1 ARRAY2 ...
 
 Creates an array iterator to return the elements of the list of arrays ARRAY1,
-ARRAY2 throughout ARRAYn in turn. That is, the first time it is called, it
-returns the first element of each array. The next time, it returns the second
-elements. And so on, until all elements are exhausted.
+ARRAY2 throughout ARRAYn in turn.  That is, the first time it is called, it
+returns the first element of each array.  The next time, it returns the second
+elements.  And so on, until all elements are exhausted.
 
 This is useful for looping over more than one array at once:
 
@@ -432,7 +448,7 @@ plain arrays.
 =head3 natatime EXPR, LIST
 
 Creates an array iterator, for looping over an array in chunks of
-C<$n> items at a time. (n at a time, get it?). An example is
+C<$n> items at a time.  (n at a time, get it?).  An example is
 probably a better explanation than I could give in words.
 
 Example:
@@ -657,7 +673,7 @@ limitation does not apply to the XS version.
 
 The maintenance goal is to preserve the documented semantics of the API;
 bug fixes that bring actual behavior in line with semantics are allowed.
-New API functions may be added over time. If a backwards incompatible
+New API functions may be added over time.  If a backwards incompatible
 change is unavoidable, we will attempt to provide support for the legacy
 API using the same export tag mechanism currently in place.
 
@@ -666,7 +682,7 @@ configuration and testing modules will be bundled when reasonable;
 run-time dependencies will be added only if they deliver substantial
 benefit.
 
-=head1 BUGS
+=head1 KNOWN ISSUES
 
 There is a problem with a bug in 5.6.x perls. It is a syntax error to write
 things like:
@@ -692,14 +708,7 @@ output of your program with the environment variable C<LIST_MOREUTILS_PP> set
 to a true value. That way I know where to look for the problem (in XS,
 pure-Perl or possibly both).
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-list-someutils@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>. I will be notified, and then you'll automatically be
-notified of progress on your bug as I make changes.
-
-=head1 CREDITS
+=head1 THANKS
 
 =head2 Tassilo von Parseval
 
@@ -710,7 +719,7 @@ tidier by making L<List::Util> obsolete.
 Brian McCauley suggested the inclusion of apply() and provided the pure-Perl
 implementation for it.
 
-Eric J. Roode asked me to add all functions from his module C<List::MoreUtil>
+Eric J. Roode asked me to add all functions from his module C<List::SomeUtil>
 into this one. With minor modifications, the pure-Perl implementations of those
 are by him.
 
@@ -756,6 +765,11 @@ my mailbox. This includes:
 
 =over 4
 
+=item * List::Util export pass-through
+
+Allow B<List::SomeUtils> to pass-through the regular L<List::Util>
+functions to end users only need to C<use> the one module.
+
 =item * uniq_by(&@)
 
 Use code-reference to extract a key based on which the uniqueness is
@@ -796,4 +810,119 @@ Copyright 2004 - 2010 by Tassilo von Parseval
 
 Copyright 2013 - 2015 by Jens Rehsack
 
+=head1 SUPPORT
+
+Bugs may be submitted at L<https://github.com/houseabsolute/List-SomeUtils/issues>.
+
+I am also usually active on IRC as 'autarch' on C<irc://irc.perl.org>.
+
+=head1 SOURCE
+
+The source code repository for List-SomeUtils can be found at L<https://github.com/houseabsolute/List-SomeUtils>.
+
+=head1 DONATIONS
+
+If you'd like to thank me for the work I've done on this module, please
+consider making a "donation" to me via PayPal. I spend a lot of free time
+creating free software, and would appreciate any support you'd care to offer.
+
+Please note that B<I am not suggesting that you must do this> in order for me
+to continue working on this particular software. I will continue to do so,
+inasmuch as I have in the past, for as long as it interests me.
+
+Similarly, a donation made in this way will probably not make me work on this
+software much more, unless I get so many donations that I can consider working
+on free software full time (let's all have a chuckle at that together).
+
+To donate, log into PayPal and send money to autarch@urth.org, or use the
+button at L<http://www.urth.org/~autarch/fs-donation.html>.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Tassilo von Parseval <tassilo.von.parseval@rwth-aachen.de>
+
+=item *
+
+Adam Kennedy <adamk@cpan.org>
+
+=item *
+
+Jens Rehsack <rehsack@cpan.org>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 CONTRIBUTORS
+
+=for stopwords Aaron Crane BackPan Brad Forschinger David Golden jddurand Jens Rehsack J.R. Mash Karen Etheridge Ricardo Signes Toby Inkster Tokuhiro Matsuno Tom Wyant
+
+=over 4
+
+=item *
+
+Aaron Crane <arc@cpan.org>
+
+=item *
+
+BackPan <BackPan>
+
+=item *
+
+Brad Forschinger <bnjf@bnjf.id.au>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+jddurand <jeandamiendurand@free.fr>
+
+=item *
+
+Jens Rehsack <sno@netbsd.org>
+
+=item *
+
+J.R. Mash <jrmash@cpan.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@cpan.org>
+
+=item *
+
+Toby Inkster <mail@tobyinkster.co.uk>
+
+=item *
+
+Tokuhiro Matsuno <tokuhirom@cpan.org>
+
+=item *
+
+Tom Wyant <wyant@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2017 by Dave Rolsky <autarch@urth.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+The full text of the license can be found in the
+F<LICENSE> file included with this distribution.
+
 =cut
